aboutsummaryrefslogtreecommitdiffstats
path: root/plugins
diff options
context:
space:
mode:
authorulfl <ulfl@f5534014-38df-0310-8fa8-9805f1628bb7>2005-02-20 22:36:34 +0000
committerulfl <ulfl@f5534014-38df-0310-8fa8-9805f1628bb7>2005-02-20 22:36:34 +0000
commit6b959c22061dd8d4b67a0e4fe8617501d17e8c51 (patch)
tree909db714be8a4d2b92b651d77bca32fb56719787 /plugins
parent42a4e0e22776d83b73b7dab2dfb18908dd2e7f55 (diff)
fix a typo: lenght -> length
This seems to be a "more common" typo, fixed it 13 times throughout the code ... git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@13452 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'plugins')
-rw-r--r--plugins/acn/packet-acn.c2
-rw-r--r--plugins/lwres/packet-lwres.c2
-rw-r--r--plugins/mate/mate_util.c4
3 files changed, 4 insertions, 4 deletions
diff --git a/plugins/acn/packet-acn.c b/plugins/acn/packet-acn.c
index 5d8169c93d..3c7b78b248 100644
--- a/plugins/acn/packet-acn.c
+++ b/plugins/acn/packet-acn.c
@@ -937,7 +937,7 @@ proto_register_acn(void) {
"res", HFILL }},
{ &hf_acn_pdu_length,
- { "Lenght","acn.pdu.length",
+ { "Length","acn.pdu.length",
FT_UINT8, BASE_DEC, NULL, 0x0,
"Length", HFILL }},
diff --git a/plugins/lwres/packet-lwres.c b/plugins/lwres/packet-lwres.c
index c30373b1c1..16de34150d 100644
--- a/plugins/lwres/packet-lwres.c
+++ b/plugins/lwres/packet-lwres.c
@@ -1450,7 +1450,7 @@ proto_register_lwres(void)
{ &hf_adn_addr_len,
{ "Address length", "lwres.adn.addr.length", FT_UINT16, BASE_DEC, NULL, 0x0,
- "lwres adn addr lenght", HFILL }},
+ "lwres adn addr length", HFILL }},
{ &hf_adn_addr_addr,
{ "IP Address", "lwres.adn.addr.addr", FT_STRING, BASE_DEC, NULL, 0x0,
diff --git a/plugins/mate/mate_util.c b/plugins/mate/mate_util.c
index baa865e532..37768d778f 100644
--- a/plugins/mate/mate_util.c
+++ b/plugins/mate/mate_util.c
@@ -1624,7 +1624,7 @@ LoAL* load_loal_error(FILE* fp, LoAL* loal, AVPL* curr, int linenum, guint8* fmt
}
/* the maximum lenght allowed for a line */
#define MAX_ITEM_LEN 8192
/* this two ugly things are used for tokenizing */
@@ -1694,7 +1694,7 @@ extern LoAL* loal_from_file(guint8* filename) {
}
if ( i >= MAX_ITEM_LEN - 1 ) {
- return load_loal_error(fp,loal,curr,linenum,"Maximum item lenght exceeded");
+ return load_loal_error(fp,loal,curr,linenum,"Maximum item length exceeded");
}
switch(state) {
@@ -1624,7 +1624,7 @@ LoAL* load_loal_error(FILE* fp, LoAL* loal, AVPL* curr, int linenum, guint8* fmt
}
-/* the maximum lenght allowed for a line */
+/* the maximum length allowed for a line */
#define MAX_ITEM_LEN 8192
/* this two ugly things are used for tokenizing */